# Copyright (c) 2000-2011, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define with()          %{expand:%%{?with_%{1}:1}%%{!?with_%{1}:0}}
%define without()       %{expand:%%{?with_%{1}:0}%%{!?with_%{1}:1}}
%define bcond_with()    %{expand:%%{?_with_%{1}:%%global with_%{1} 1}}
%define bcond_without() %{expand:%%{!?_without_%{1}:%%global with_%{1} 1}}

%define section         free

Name:           wikitext
Version:        1.2
Release:        1%{?dist}
Epoch:          0
Summary:        Eclipse Mylyn Wikitext Maven Build by Fusesource
License:        EPL 1.0
Url:            http://wikitext.fusesource.org/maven/1.0/
Group:          Development/Libraries/Java
# git clone git://github.com/fusesource/wikitext.git
# cd wikitext/
# git-tag -l
# mkdir  ../wikitext-1.2
# git archive wikitext-project-1.2 | tar -x -C ../wikitext-1.2
# cd ..
# tar czf ../SOURCES/wikitext-1.2.tgz wikitext-1.2/
Source0:        wikitext-1.2.tgz
Source1:        %{name}-settings.xml
Source2:        %{name}-jpp-depmap.xml

BuildRequires:  jpackage-utils >= 0:1.7.5
BuildRequires:  java-devel >= 0:1.6.0
BuildRequires:  ant >= 0:1.7.1
BuildRequires:  junit >= 0:3.8.2

BuildRequires:  maven2 >= 2.0.8
BuildRequires:  maven2-plugin-compiler
BuildRequires:  maven2-plugin-install
BuildRequires:  maven2-plugin-jar
BuildRequires:  maven2-plugin-javadoc
BuildRequires:  maven2-plugin-project-info-reports
BuildRequires:  maven2-plugin-resources
BuildRequires:  maven-surefire-maven-plugin
BuildRequires:  maven-surefire-provider-junit
BuildRequires:  apache-commons-parent
BuildRequires:  mojo-parent

Requires:  java >= 0:1.6.0

Requires(post):    jpackage-utils >= 0:1.7.5
Requires(postun):  jpackage-utils >= 0:1.7.5

BuildArch:      noarch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root

%description
Mylyn WikiText provides an extensible framework and tools 
for parsing, editing and presenting lightweight markup, 
including:
* Editor for wiki files using a source editor paradigm 
  with preview
* Mylyn task editor integration making the task editor 
  markup-aware for displaying and editing markup
* Ant Tasks for converting markup to other formats
* API a framework and API for handling lightweight markup 
WikiText has parsers for MediaWiki, Textile, Confluence, 
TracWiki and TWiki markup, and can be extended to support 
other languages. WikiText provides Ant tasks for converting 
lightweight markup to HTML, Eclipse Help, DocBook, DITA and 
XSL-FO. WikiText also provides an editor for editing such 
markup within Eclipse, and integrates with the Mylyn task 
editor causing it to be markup-aware. WikiText provides 
API for integrating wiki markup capabilities into Eclipse, 
RCP, stand-alone and server-side applications. 

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Documentation

%description javadoc
%{summary}.

%prep
%setup -q 
cp -p %{SOURCE1} settings.xml
#%patch0 -p0

%build
sed -i -e "s|<url>__JPP_URL_PLACEHOLDER__</url>|<url>file://`pwd`/.m2/repository</url>|g" settings.xml
sed -i -e "s|<url>__JAVADIR_PLACEHOLDER__</url>|<url>file://`pwd`/external_repo</url>|g" settings.xml
sed -i -e "s|<url>__MAVENREPO_DIR_PLACEHOLDER__</url>|<url>file://`pwd`/.m2/repository</url>|g" settings.xml
sed -i -e "s|<url>__MAVENDIR_PLUGIN_PLACEHOLDER__</url>|<url>file:///usr/share/maven2/plugins</url>|g" settings.xml
sed -i -e "s|<url>__ECLIPSEDIR_PLUGIN_PLACEHOLDER__</url>|<url>file:///usr/share/eclipse/plugins</url>|g" settings.xml

export MAVEN_REPO_LOCAL=$(pwd)/.m2/repository
mkdir -p $MAVEN_REPO_LOCAL

mkdir external_repo
ln -s %{_javadir} external_repo/JPP

mvn-jpp \
        -e \
        -s $(pwd)/settings.xml \
        -Dmaven2.jpp.depmap.file=%{SOURCE2} \
        -Dmaven.repo.local=$MAVEN_REPO_LOCAL \
        -Dmaven.test.failure.ignore=true \
        install javadoc:aggregate 

%install
rm -rf $RPM_BUILD_ROOT
install -d -m 755 $RPM_BUILD_ROOT%{_datadir}/maven2/poms
install -d -m 755 $RPM_BUILD_ROOT%{_javadir}
install -m 644 pom.xml \
    $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP-%{name}-project.pom
%add_to_maven_depmap org.fusesource.wikitext wikitext-project %{version} JPP %{name}-project
install -m 644 org.eclipse.mylyn.wikitext.core/target/wikitext-core-%{version}.jar \
               $RPM_BUILD_ROOT%{_javadir}/%{name}-core-%{version}.jar
install -m 644 org.eclipse.mylyn.wikitext.core/pom.xml \
    $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP-%{name}-core.pom
%add_to_maven_depmap org.fusesource.wikitext wikitext-core %{version} JPP %{name}-core
install -m 644 org.eclipse.mylyn.wikitext.confluence.core/target/confluence-core-%{version}.jar \
               $RPM_BUILD_ROOT%{_javadir}/%{name}-confluence-core-%{version}.jar
install -m 644 org.eclipse.mylyn.wikitext.confluence.core/pom.xml \
    $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP-%{name}-confluence-core.pom
%add_to_maven_depmap org.fusesource.wikitext confluence-core %{version} JPP %{name}-confluence-core
install -m 644 org.eclipse.mylyn.wikitext.mediawiki.core/target/mediawiki-core-%{version}.jar \
               $RPM_BUILD_ROOT%{_javadir}/%{name}-mediawiki-core-%{version}.jar
install -m 644 org.eclipse.mylyn.wikitext.mediawiki.core/pom.xml \
    $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP-%{name}-mediawiki-core.pom
%add_to_maven_depmap org.fusesource.wikitext mediawiki-core %{version} JPP %{name}-mediawiki-core
install -m 644 org.eclipse.mylyn.wikitext.textile.core/target/textile-core-%{version}.jar \
               $RPM_BUILD_ROOT%{_javadir}/%{name}-textile-core-%{version}.jar
install -m 644 org.eclipse.mylyn.wikitext.textile.core/pom.xml \
    $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP-%{name}-textile-core.pom
%add_to_maven_depmap org.fusesource.wikitext textile-core %{version} JPP %{name}-textile-core
install -m 644 org.eclipse.mylyn.wikitext.tracwiki.core/target/tracwiki-core-%{version}.jar \
               $RPM_BUILD_ROOT%{_javadir}/%{name}-tracwiki-core-%{version}.jar
install -m 644 org.eclipse.mylyn.wikitext.tracwiki.core/pom.xml \
    $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP-%{name}-tracwiki-core.pom
%add_to_maven_depmap org.fusesource.wikitext tracwiki-core %{version} JPP %{name}-tracwiki-core
install -m 644 org.eclipse.mylyn.wikitext.twiki.core/target/twiki-core-%{version}.jar \
               $RPM_BUILD_ROOT%{_javadir}/%{name}-twiki-core-%{version}.jar
install -m 644 org.eclipse.mylyn.wikitext.twiki.core/pom.xml \
    $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP-%{name}-twiki-core.pom
%add_to_maven_depmap org.fusesource.wikitext twiki-core %{version} JPP %{name}-twiki-core

(cd $RPM_BUILD_ROOT%{_javadir} && for jar in *-%{version}.jar; do ln -sf ${jar} `echo $jar| sed  "s|-%{version}||g"`; done)


# javadoc
install -d -m 755 $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
cp -pr target/site/apidocs/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{name}

install -d -m 755 $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}
install -m 644 license.html $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}

%clean
rm -rf $RPM_BUILD_ROOT

%post
%update_maven_depmap

%postun
%update_maven_depmap 

%files
%defattr(0644,root,root,0755)
%{_javadir}/*.jar
%{_datadir}/maven2/poms/*
%{_mavendepmapfragdir}/*
%dir %{_docdir}/%{name}-%{version}
%doc %{_docdir}/%{name}-%{version}/license.html

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-%{version}
%{_javadocdir}/%{name}

%changelog
* Sun Oct 30 2011 Ralph Apel <r.apel@r-apel.de> 0:1.2-1
- 1.2

* Sat Oct 29 2011 Ralph Apel <r.apel@r-apel.de> 0:1.0-1
- First release

